#!/bin/bash

export PDBID="Water"
export CUDA_VISIBLE_DEVICES=0

# Energy minimization was done in prepSystem.sh
cd /home/cerutti/FF15Redux/OctWater/Prep/
cp min.rst ${PDBID}_Eq0.rst

# Restrained Equilibration
PNUM=0
NUM=1
RSEED=8174
for RESTWT in 4.0 1.0 0.25 0.0625 ; do

  NSTEP=50000
  TSTEP=0.0015
  NTX=5
  IREST=1
  if [ ${NUM} -eq 1 ] ; then
    NSTEP=50000
    TSTEP=0.001
    NTX=1
    IREST=0
  fi
  if [ ${NUM} -gt 4 ] ; then
    TSTEP=0.002
  fi

cat > mdequil${PNUM}.in << EOF
Standard MD run file
 &cntrl

  nmropt = 0,
  ntx    = ${NTX},       irest  = ${IREST},       ntrx   = 1,      ntxo   = 1,
  ntpr   = 1000,    ntwx   = 1000,    ntwv   = 0,      ntwe   = 1000,
  iwrap  = 0,       ioutfm = 1,

  ntf    = 2,       ntb    = 2,
  cut = 8.0,

  ibelly = 0,       ntr    = 0,

  imin   = 0,
  nstlim = ${NSTEP},
  nscm   = 1000,
  t      = 0.0,     dt     = ${TSTEP},

  temp0     = 298.0,   tempi  =  0.0,
  ig        = ${RSEED},
  ntt       = 3,
  gamma_ln  = 3.0,

  ntp    = 1,       pres0  = 1.0,     comp   = 44.6,
  taup   = 1.0,

  ntc    = 2,       tol    = 0.000001, watnam = 'WAT ',

 &end
 &ewald
  dsum_tol = 1.0e-5,
  skinnb   = 1.0,
 &end
EOF
  let "RSEED+=1"

  if [ ! -e ${PDBID}_Eq${NUM}.rst ] ; then
    /home/cerutti/amberPBC/bin/pmemd.cuda_SPFP -O \
      -i mdequil${PNUM}.in \
      -o ${PDBID}_Eq${NUM}.out \
      -c ${PDBID}_Eq${PNUM}.rst \
      -r ${PDBID}_Eq${NUM}.rst \
      -e ${PDBID}_Eq${NUM}.en \
      -ref ${PDBID}_Eq${PNUM}.rst \
      -p ${PDBID}.top \
      < /dev/null
  fi

  let "NUM+=1"
  let "PNUM+=1"

done
